@@ -7,7 +7,7 @@ from importlib.metadata import version
 from time import sleep
 from threading import Thread, Event
 
-from .job import NumerousBaseJob
+from .job import NumerousBaseJob, ExitCode
 from .errors import tb_str
 from numerous_cli.client import get_client
 from numerous_api_client.client import NumerousClient
@@ -15,19 +15,15 @@ from numerous_api_client.client.numerous_client import ScenarioStatus
 
 VERSION = version('numerous_image_tools')
 APPVERSION = os.getenv('APPVERSION', "?")
-APPNAME = os.getenv('APPNAME')
-LOG_LEVEL = os.getenv('LOG_LEVEL', logging.INFO)
-MODEL = os.getenv('MODEL')
-MAX_RESTARTS = int(os.getenv('MAX_RESTARTS', 0))
 
 local = os.getenv('KUBERNETES_SERVICE_HOST',"") == ""
-logger = logging.getLogger('numerous-image-tools')
-logger.setLevel(level=LOG_LEVEL)
 
 class NumerousApp():
     def __init__(self, numerous_client: NumerousClient = None,
                  appname = "defaultnumerousApp",
                  max_restarts = 0, numerous_job: NumerousBaseJob = None, model_folder: str = None):
+        log_level = os.getenv('LOG_LEVEL', logging.root.level)
+
         self.appname = appname
         self.nc = numerous_client
 
@@ -48,9 +44,8 @@ class NumerousApp():
         self.end_time = None
         self.max_restarts = max_restarts
         self.status = 0
-        self.message = ""
         self.logger = logging.getLogger(self.appname)
-        self.logger.setLevel(level=LOG_LEVEL)
+        self.logger.setLevel(level=log_level)
         self.model_folder = model_folder
         self.numerous_job = numerous_job
 
@@ -81,10 +76,10 @@ class NumerousApp():
 
         while not self.terminate.is_set():
             checkpoint_time = datetime.datetime.now()
-            if not thread.is_alive() and self.status == -1:
+            if not thread.is_alive() and self.numerous_job._exit_code.value <= ExitCode.ERROR.value:
                 if not warned:
                     self.nc.set_scenario_progress(message=
-                                                  f"{self.message}. Retrying after 5 mins "
+                                                  f"{self.numerous_job._exit_code.description}. Retrying after 5 mins "
                                                   f"({restarts + 1}/{self.max_restarts})",
                                                   status=ScenarioStatus.RUNNING, force=True)
                     warned = True
@@ -92,7 +87,6 @@ class NumerousApp():
                         restarts < self.max_restarts:
                     self.logger.error(f'{self.appname} is dead.. restarting')
                     self.status = 0
-                    self.message = ""
                     thread = Thread(target=self.numerous_job._start, args=(self, ), daemon=False)
                     thread.start()
                     sleep(5)
@@ -104,6 +98,10 @@ class NumerousApp():
                     self.logger.error(f'{self.appname} is dead and reached max restarts')
                     break
 
+            elif not thread.is_alive():
+                self.logger.debug(f'thread has ended with code {self.status}')
+                break
+
             if checkpoint(checkpoint_time, last_checkpoint):
                 self.backup.set()
                 last_checkpoint = checkpoint_time
@@ -115,8 +113,6 @@ class NumerousApp():
         self.logger.info("Main thread stopped gracefully")
 
 
-
-
 def checkpoint(tnow, tlast, interval=60):
     dt=datetime.timedelta(minutes=interval)
     if tnow-tlast > dt:
@@ -128,6 +124,9 @@ def run_job(numerous_job=None, appname=None, max_restarts=0, model_folder="model
     """
     Runs the simulation job with the model located in model_folder_name. Handles all events.
     """
+    log_level = os.getenv('LOG_LEVEL', logging.root.level)
+    logger = logging.getLogger('numerous-image-tools')
+    logger.setLevel(level=log_level)
 
     def handler(sig, frame):
         logger.debug(f'main thread received {sig} {frame}')
@@ -144,33 +143,25 @@ def run_job(numerous_job=None, appname=None, max_restarts=0, model_folder="model
         else:
             nc = NumerousClient()
 
-        nc.logger.setLevel(LOG_LEVEL)
+        nc.logger.setLevel(log_level)
 
         if numerous_job is None:
             raise KeyError("no simulation job specified")
         if appname is None:
             logger.warning("no appname specified")
 
-        logger.info(f"Welcome to numerous image tools. Base version {VERSION} - app {APPNAME} version {APPVERSION}")
+        logger.info(f"Welcome to numerous image tools. Base version {VERSION} - app {appname}")
 
         app = NumerousApp(numerous_client=nc, appname=appname,
                           max_restarts=max_restarts, numerous_job=numerous_job, model_folder=model_folder)
 
         app.loop()
 
-        if app.status == -1:
-            nc.set_scenario_progress(app.message, ScenarioStatus.FAILED, 0, force=True)
-        elif app.status == 0:
-            nc.set_scenario_progress("interrupted", ScenarioStatus.FINISHED, force=True)
-        elif app.status == 1:
-            nc.set_scenario_progress(app.message, ScenarioStatus.FINISHED, 100, force=True)
-        elif app.status == 2:
-            nc.set_scenario_progress("hibernating", ScenarioStatus.HIBERNATING, force=True)
-        else:
-            nc.set_scenario_progress("unknown", ScenarioStatus.FINISHED, force=True)
+        nc.set_scenario_progress(numerous_job._exit_code.description, numerous_job._exit_code.scenariostatus,
+                                 force=True)
 
-        logger.debug(f'setting state {app.status}')
-        nc.state.set('_status', app.status)
+        logger.debug(f'setting state {numerous_job._exit_code}')
+        nc.state.set('_status', numerous_job._exit_code.name)
 
     except Exception as e:
         logger.error(f"unhandled exception: {tb_str(e)}")
