@@ -6,6 +6,7 @@ import sys
 import logging
 import importlib
 from pathlib import Path
+from numerous_image_tools.errors import tb_str
 
 logger = logging.getLogger('sim-setup')
 
@@ -59,13 +60,15 @@ class Project:
 class NumerousSystem:
     def __init__(self, nc: NumerousClient=None, scenario=None, files=None, start_time=None, end_time=None,
                  model_folder=None, numerous_job=None,
-                 states=None, dt=None):
+                 states=None, t=None, dt=None, input=None):
 
         self.nc = nc
         self.scenario = scenario
         self.files = files
         self.start_time = start_time
         self.end_time = end_time
+        self._initialized = False
+        self.logger = logging.getLogger('NumerousSystem')
 
         # Update status - clear current data
         self.nc.set_scenario_progress('Environment Initializing',ScenarioStatus.ENVIRONMENT_INITIALIZING, 0.0, clean=True)
@@ -86,8 +89,17 @@ class NumerousSystem:
             if 'id' in par and 'value' in par:
                 self.parameters.update({par.get('id'): par.get('value')})
 
-        logger.debug("completed setup")
+        self.input = input
 
+        try:
+            data = self.input.get_at_time(t)
+            self.update_inputs(data)
+            self.initialize_model()
+        except Exception as e:
+
+            self.logger.error(f"could not initialize model {tb_str(e)}")
+
+        self.logger.debug("completed setup")
 
     def _add_path_topdown(self, top):
         if top in sys.path:
@@ -107,7 +119,7 @@ class NumerousSystem:
         for component in self.components.values():
             component.model = component._initialize(self)
 
-        return self.numerous_job.initialize_simulation_system()
+        self._initialized = True
 
     def _dynamic_import_components(self):
         for component in self.components.values():
@@ -115,6 +127,8 @@ class NumerousSystem:
             component._dynamicimport()
 
     def update_inputs(self, data):
+        if data is None:
+            return
         component_data = copy.deepcopy(data)
         component_data.pop('_index')
         component_data.pop('_index_relative')
@@ -171,7 +185,7 @@ def format_job_spec(scenario, model_folder_name):
                                   folder=f"{model_folder_name}/{model_name}",
                                   path=f"{model_folder_name}.{model_name}.{model_file_name}", handle=handle,
                                   constants=component_constants,
-                                  parameters=component_parameters, import_flag=bool(item_class))
+                                  parameters=component_parameters, import_flag=bool(item_class) and model_folder_name)
             component_list.append(component)
             components.update({component_name: component})
 
